@@ -242,10 +242,12 @@ def _survey_report_url(survey):
 
 def allowed_actions(request, slug):
     survey = _get_survey_or_404(slug, request)
+    authenticated = request.user.is_authenticated()
     response = HttpResponse(mimetype='application/json')
     dump({"enter": _can_show_form(request, survey),
           "view": survey.can_have_public_submissions(),
-          "open": survey.is_open}, response)
+          "open": survey.is_open,
+          "need_login": survey.require_login and not authenticated}, response)
     return response
 
 
@@ -373,9 +375,10 @@ def submissions(request, format):
         results = results[:limit]
     answer_lookup = get_all_answers(results,
                                     include_private_questions=is_staff)
-    result_data = [result.to_jsondata(
-        answer_lookup,
-        include_private_questions=is_staff) for result in results]
+    result_data = []
+    for r in results:
+        data = r.to_jsondata(answer_lookup, include_private_questions=is_staff)
+        result_data.append(data)
 
     for data in result_data:
         data.update(data["data"])
